SystemOrganization addCategory: #ConfigurationOfNumberExtensions!

Object subclass: #ConfigurationOfNumberExtensions
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfNumberExtensions'!

!ConfigurationOfNumberExtensions commentStamp: '<historical>' prior: 0!
Copy me to create a new configuration or edit and evaluate the following doits.

        "Create configuration class and initial baseline method"

        MetacelloToolBox 
                createBaseline: '1.0-baseline'
                for: 'MyProject'
                repository: 'http://www.example.com/MyProjectRepository'
                requiredProjects: #('Gofer')
                packages: #('MyProject-Core' 'MyProject-Tests')
                dependencies:
                        {('MyProject-Core' -> #('Gofer')).
                         ('MyProject-Tests' -> #('MyProject-Core'))}
                groups:
                        {('default' -> #('Core')).
                        ('Core' -> #('MyProject-Core')).
                        ('Tests' -> #('MyProject-Tests'))}.

	   "create initial development method from the baseline"

         MetacelloToolBox
               createDevelopment: '1.0'
               for: 'MyProject'
                importFromBaseline: '1.0-baseline'
                description: 'initial version'.
!

!ConfigurationOfNumberExtensions class methodsFor: 'development support' stamp: 'nice 3/20/2014 01:24'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfNumberExtensions class methodsFor: 'private' stamp: 'nice 3/20/2014 01:24'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfNumberExtensions class methodsFor: 'catalog' stamp: 'nice 3/20/2014 22:29'!
catalogChangeLog
	"Returns a paragraph describing the most important changes in the configuration class."
	^ '- 1.0 - 2014/03/19 - version ported to Pharo 3.0
[[[
	( ConfigurationOfNumberExtensions project version: ''1.0'' ) load.					
]]]'! !

!ConfigurationOfNumberExtensions class methodsFor: 'catalog' stamp: 'nice 3/20/2014 22:30'!
catalogContactInfo
	"Returns a paragraph describing contact information such as email, mailing lists and website."
	^ 'Math-NumberExtensions is maintained by nicolas.cellier.aka.nice@gmail.com'! !

!ConfigurationOfNumberExtensions class methodsFor: 'catalog' stamp: 'nice 3/20/2014 22:31'!
catalogDescription
	"Returns a paragraph describing the project"
	^ 'Math-NumberExtensions package adds a few mathematical functions (hyperbolic) to Smalltalk numbers.'! !

!ConfigurationOfNumberExtensions class methodsFor: 'catalog' stamp: 'nice 3/20/2014 22:35'!
catalogKeyClassesAndExample
	"Returns a paragraph or more describing the key classes of your project. You can use Pillar/Pier syntax to layout out the text i.e., ==Code== and - for bullet."
	^ 'Math-NumberExtensions just provide extensions to Number and subclasses.
- the cosh sinh and tanh hyperbolic functions
- the arCosh arSinh arTanh inverse hyperbolic functions
These functions have easy implementations when no special care in term of accuracy nor monotonicity is required.'! !

!ConfigurationOfNumberExtensions class methodsFor: 'catalog' stamp: 'nice 3/20/2014 22:35'!
catalogKeywords
	"Returns an array of symbols"
	^ #(math number hyperbolic) ! !

!ConfigurationOfNumberExtensions class methodsFor: 'private' stamp: 'nice 3/20/2014 01:24'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfNumberExtensions class methodsFor: 'private' stamp: 'nice 3/20/2014 01:24'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfNumberExtensions class methodsFor: 'metacello tool support' stamp: 'nice 3/20/2014 01:24'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfNumberExtensions class methodsFor: 'loading' stamp: 'nice 3/20/2014 01:24'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfNumberExtensions class methodsFor: 'loading' stamp: 'nice 3/20/2014 01:24'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfNumberExtensions class methodsFor: 'loading' stamp: 'nice 3/20/2014 01:24'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfNumberExtensions class methodsFor: 'accessing' stamp: 'nice 3/20/2014 01:24'!
project

	^self new project! !

!ConfigurationOfNumberExtensions class methodsFor: 'development support' stamp: 'nice 3/20/2014 01:24'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfNumberExtensions methodsFor: 'baselines' stamp: 'nice 3/20/2014 01:28'!
baseline10: spec
	<version: '1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://www.squeaksource.com/NumberExtensions'.
		spec package: 'Math-Number-Extensions' with: [spec requires: #()].
		spec
			group: 'default' with: #('Core');
			group: 'Core' with: #( 'Math-Number-Extensions');
			yourself].! !

!ConfigurationOfNumberExtensions methodsFor: 'accessing' stamp: 'nice 3/20/2014 01:24'!
customProjectAttributes
	 "Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes"

	^ #().! !

!ConfigurationOfNumberExtensions methodsFor: 'symbolic versions' stamp: 'nice 3/20/2014 01:28'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '1.0'! !

!ConfigurationOfNumberExtensions methodsFor: 'accessing' stamp: 'nice 3/20/2014 01:24'!
project

	^ project ifNil: [ 
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		project := MetacelloMCProject new projectAttributes: self customProjectAttributes. 
		(Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfNumberExtensions methodsFor: 'symbolic versions' stamp: 'nice 3/20/2014 01:29'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '1.0'! !

!ConfigurationOfNumberExtensions methodsFor: 'versions' stamp: 'nice 3/20/2014 01:31'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'initial version'.
		spec author: 'nice'.
		spec timestamp: '2014/03/20 01:29'.].
		spec for: #squeak do:[
			spec
			package: 'Math-Number-Extensions' with: 'Math-Number-Extensions-nice.5'. ].
		spec for: #pharo do:[
			spec
			package: 'Math-Number-Extensions' with: 'Math-Number-Extensions.Pharo-nice.6'. ].
! !
